Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "SymmetryInterface");
;//5.0.1-v4 Tue Sep 10 11:29:27 CDT 2024
